@@ -66,6 +66,7 @@ newuoaControl <- function(npt=NULL,
                           rxControl=NULL,
                           optExpression=TRUE, sumProd=FALSE,
                           literalFix=TRUE,
+                          literalFixRes=TRUE,
                           addProp = c("combined2", "combined1"),
                           calcTables=TRUE, compress=TRUE,
                           covMethod=c("r", ""),
@@ -79,6 +80,7 @@ newuoaControl <- function(npt=NULL,
 
   checkmate::assertLogical(optExpression, len=1, any.missing=FALSE)
   checkmate::assertLogical(literalFix, len=1, any.missing=FALSE)
+  checkmate::assertLogical(literalFixRes, len=1, any.missing=FALSE)
   checkmate::assertLogical(sumProd, len=1, any.missing=FALSE)
   checkmate::assertLogical(returnNewuoa, len=1, any.missing=FALSE)
   checkmate::assertLogical(calcTables, len=1, any.missing=FALSE)
@@ -157,6 +159,7 @@ newuoaControl <- function(npt=NULL,
                covMethod=match.arg(covMethod),
                optExpression=optExpression,
                literalFix=literalFix,
+               literalFixRes=literalFixRes,
                sumProd=sumProd,
                rxControl=rxControl,
                returnNewuoa=returnNewuoa,
@@ -257,6 +260,7 @@ getValidNlmixrCtl.newuoa <- function(control) {
                                 sumProd=.newuoaControl$sumProd,
                                 optExpression=.newuoaControl$optExpression,
                                 literalFix=.newuoaControl$literalFix,
+                                literalFixRes=.newuoaControl$literalFixRes,
                                 scaleTo=0,
                                 calcTables=.newuoaControl$calcTables,
                                 addProp=.newuoaControl$addProp,
