@@ -1,7 +1,5 @@
 nmTest({
-
   test_that("addCwres", {
-
     one.compartment <- function() {
       ini({
         tka <- log(1.57)
@@ -21,7 +19,7 @@ nmTest({
     }
 
     suppressMessages(
-      fitNoEta <- nlmixr2(one.compartment, theo_sd,  est="focei", control = list(print=0))
+      fitNoEta <-.nlmixr(one.compartment, theo_sd, est="focei", control = list(print=0))
     )
     expect_true(inherits(fitNoEta$parHistData, "data.frame"))
     expect_error(
@@ -31,7 +29,6 @@ nmTest({
   })
 
   test_that("cwres issue in 3.0.3", {
-
     skip_if_not(file.exists(test_path("test-cwres-3.0.3.qs")))
 
     data <- qs::qread(test_path("test-cwres-3.0.3.qs"))
@@ -55,14 +52,8 @@ nmTest({
       })
     }
 
-    test_run001 <-
-      nlmixr2(
-        test_model(),
-        data,
-        "saem",
-        control=list(print=0, nBurn=1, nEm=1))
+    test_run001 <- .nlmixr(test_model(), data, "saem", control = saemControlFast)
 
     expect_error(addCwres(test_run001), NA)
-
   })
 })
