@@ -18,7 +18,7 @@ test_that("all theta parameters are fixed", {
     })
   }
 
-  f <- nlmixr2(
+  f <-.nlmixr(
     one.compartment, data = theo_sd, est="saem", control = saemControl(print=0, nEm=10, nBurn=10, literalFix=FALSE))
 
   expect_true(inherits(f, "nlmixr2FitData"))
@@ -27,7 +27,7 @@ test_that("all theta parameters are fixed", {
 
   expect_error(m2$saemModelPred, NA)
 
-  f <- nlmixr2(
+  f <-.nlmixr(
     one.compartment, data = theo_sd, est="saem", control = saemControl(print=0, nEm=10, nBurn=10, literalFix=TRUE))
 
   expect_true(inherits(f, "nlmixr2FitData"))
